diff --git a/apps/wei/tests/test_wei_algorithm_2021.py b/apps/wei/tests/test_wei_algorithm_2021.py
index ccac4c9d9c850599c72a1140d810b40932171784..cbc06f4e47bbf3518f206be26ea4f52a24002f5d 100644
--- a/apps/wei/tests/test_wei_algorithm_2021.py
+++ b/apps/wei/tests/test_wei_algorithm_2021.py
@@ -102,6 +102,6 @@ class TestWEIAlgorithm(TestCase):
             max_score = buses[0][1]
             penalty += (max_score - score) ** 2
 
-            self.assertLessEqual(max_score - score, 20)  # Always less than 20 % of tolerance
+            self.assertLessEqual(max_score - score, 25)  # Always less than 25 % of tolerance
 
         self.assertLessEqual(penalty / 100, 25)  # Tolerance of 5 %